@@ -44,8 +44,6 @@ class RuntimeEnvironment:
     cuda_version = attr.ib(type=str, default=None)
     name = attr.ib(type=str, default=None)
 
-    _fully_specified = attr.ib(type=Optional[bool], default=None)
-
     @classmethod
     def load(cls, content: Optional[str] = None) -> "RuntimeEnvironment":
         """Load runtime environment information from file or from a JSON representation, transparently."""
@@ -95,8 +93,6 @@ class RuntimeEnvironment:
     def to_dict(self, without_none: bool = False) -> Dict[str, Any]:
         """Convert runtime environment configuration to a dict representation."""
         dict_ = attr.asdict(self)
-        # Do not propagate private property.
-        dict_.pop("_fully_specified", None)
         if not without_none:
             return dict_
 
@@ -124,15 +120,12 @@ class RuntimeEnvironment:
         return str(dict_representation)
 
     def is_fully_specified(self) -> bool:
-        """Pre-cache check if the given runtime environment is fully specified."""
-        if self._fully_specified is None:
-            runtime_environment = (
-                self.operating_system.name,
-                self.operating_system.version,
-                self.python_version,
-            )
-            self._fully_specified = all(
-                i is not None for i in runtime_environment
-            )
-
-        return self._fully_specified
+        """Check if the given runtime environment is fully specified."""
+        runtime_environment = (
+            self.operating_system.name,
+            self.operating_system.version,
+            self.python_version,
+        )
+        return all(
+            i is not None for i in runtime_environment
+        )
